@@ -1,3 +1,4 @@
+"""Unix."""
 from __future__ import annotations
 
 import os
@@ -10,7 +11,8 @@ from .api import PlatformDirsABC
 if sys.platform == "win32":
 
     def getuid() -> int:
-        raise RuntimeError("should only be used on Unix")
+        msg = "should only be used on Unix"
+        raise RuntimeError(msg)
 
 else:
     from os import getuid
@@ -37,7 +39,7 @@ class Unix(PlatformDirsABC):
         """
         path = os.environ.get("XDG_DATA_HOME", "")
         if not path.strip():
-            path = os.path.expanduser("~/.local/share")
+            path = os.path.expanduser("~/.local/share")  # noqa: PTH111
         return self._append_app_name_and_version(path)
 
     @property
@@ -57,7 +59,7 @@ class Unix(PlatformDirsABC):
         path_list = path.split(os.pathsep)
         if not self.multipath:
             path_list = path_list[0:1]
-        path_list = [self._append_app_name_and_version(os.path.expanduser(p)) for p in path_list]
+        path_list = [self._append_app_name_and_version(os.path.expanduser(p)) for p in path_list]  # noqa: PTH111
         return os.pathsep.join(path_list)
 
     @property
@@ -68,7 +70,7 @@ class Unix(PlatformDirsABC):
         """
         path = os.environ.get("XDG_CONFIG_HOME", "")
         if not path.strip():
-            path = os.path.expanduser("~/.config")
+            path = os.path.expanduser("~/.config")  # noqa: PTH111
         return self._append_app_name_and_version(path)
 
     @property
@@ -92,15 +94,13 @@ class Unix(PlatformDirsABC):
         """
         path = os.environ.get("XDG_CACHE_HOME", "")
         if not path.strip():
-            path = os.path.expanduser("~/.cache")
+            path = os.path.expanduser("~/.cache")  # noqa: PTH111
         return self._append_app_name_and_version(path)
 
     @property
     def site_cache_dir(self) -> str:
-        """
-        :return: cache directory shared by users, e.g. ``/var/tmp/$appname/$version``
-        """
-        return self._append_app_name_and_version("/var/tmp")
+        """:return: cache directory shared by users, e.g. ``/var/tmp/$appname/$version``"""
+        return self._append_app_name_and_version("/var/tmp")  # noqa: S108
 
     @property
     def user_state_dir(self) -> str:
@@ -110,45 +110,35 @@ class Unix(PlatformDirsABC):
         """
         path = os.environ.get("XDG_STATE_HOME", "")
         if not path.strip():
-            path = os.path.expanduser("~/.local/state")
+            path = os.path.expanduser("~/.local/state")  # noqa: PTH111
         return self._append_app_name_and_version(path)
 
     @property
     def user_log_dir(self) -> str:
-        """
-        :return: log directory tied to the user, same as `user_state_dir` if not opinionated else ``log`` in it
-        """
+        """:return: log directory tied to the user, same as `user_state_dir` if not opinionated else ``log`` in it"""
         path = self.user_state_dir
         if self.opinion:
-            path = os.path.join(path, "log")
+            path = os.path.join(path, "log")  # noqa: PTH118
         return path
 
     @property
     def user_documents_dir(self) -> str:
-        """
-        :return: documents directory tied to the user, e.g. ``~/Documents``
-        """
+        """:return: documents directory tied to the user, e.g. ``~/Documents``"""
         return _get_user_media_dir("XDG_DOCUMENTS_DIR", "~/Documents")
 
     @property
     def user_pictures_dir(self) -> str:
-        """
-        :return: pictures directory tied to the user, e.g. ``~/Pictures``
-        """
+        """:return: pictures directory tied to the user, e.g. ``~/Pictures``"""
         return _get_user_media_dir("XDG_PICTURES_DIR", "~/Pictures")
 
     @property
     def user_videos_dir(self) -> str:
-        """
-        :return: videos directory tied to the user, e.g. ``~/Videos``
-        """
+        """:return: videos directory tied to the user, e.g. ``~/Videos``"""
         return _get_user_media_dir("XDG_VIDEOS_DIR", "~/Videos")
 
     @property
     def user_music_dir(self) -> str:
-        """
-        :return: music directory tied to the user, e.g. ``~/Music``
-        """
+        """:return: music directory tied to the user, e.g. ``~/Music``"""
         return _get_user_media_dir("XDG_MUSIC_DIR", "~/Music")
 
     @property
@@ -189,18 +179,18 @@ def _get_user_media_dir(env_var: str, fallback_tilde_path: str) -> str:
     if media_dir is None:
         media_dir = os.environ.get(env_var, "").strip()
         if not media_dir:
-            media_dir = os.path.expanduser(fallback_tilde_path)
+            media_dir = os.path.expanduser(fallback_tilde_path)  # noqa: PTH111
 
     return media_dir
 
 
 def _get_user_dirs_folder(key: str) -> str | None:
-    """Return directory from user-dirs.dirs config file. See https://freedesktop.org/wiki/Software/xdg-user-dirs/"""
-    user_dirs_config_path = os.path.join(Unix().user_config_dir, "user-dirs.dirs")
-    if os.path.exists(user_dirs_config_path):
+    """Return directory from user-dirs.dirs config file. See https://freedesktop.org/wiki/Software/xdg-user-dirs/."""
+    user_dirs_config_path = Path(Unix().user_config_dir) / "user-dirs.dirs"
+    if user_dirs_config_path.exists():
         parser = ConfigParser()
 
-        with open(user_dirs_config_path) as stream:
+        with user_dirs_config_path.open() as stream:
             # Add fake section header, so ConfigParser doesn't complain
             parser.read_string(f"[top]\n{stream.read()}")
 
@@ -209,7 +199,7 @@ def _get_user_dirs_folder(key: str) -> str | None:
 
         path = parser["top"][key].strip('"')
         # Handle relative home paths
-        path = path.replace("$HOME", os.path.expanduser("~"))
+        path = path.replace("$HOME", os.path.expanduser("~"))  # noqa: PTH111
         return path
 
     return None
